##  Set Up a Key Performance Indicator (KPI) Dashboard
To monitor application modernization effectively, configure a KPI-driven dashboard to get a comprehensive view of risk, complexity, cost, and readiness. Learn how to work with KPIs in [KPIs](https://help.sap.com/docs/leanix/ea/kpis?locale=en-US&state=PRODUCTION&version=CLOUD "Configure KPIs and display them on dashboards to track enterprise architecture metrics.").
Example of Dashboard with Modernization KPIs
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loiod1bdc3a5d86947b28318e6e634800731_LowRes.png)
